#!/bin/bash

# Copyright © 2016, 2017 Mohamed El Morabity <melmorabity@fedoraproject.com>
#
# This module is free software: you can redistribute it and/or modify it under
# the terms of the GNU General Public License as published by the Free Software
# Foundation, either version 3 of the License, or (at your option) any later
# version.
#
# This software is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
# FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along with
# this program. If not, see <http://www.gnu.org/licenses/>.
#
# Extended 2018 Thomas Wagner <wagner-thomas@gmx.at> 
# 	now runs without utils.sh
#	supports second argument, if non empty: check for mounts instead of service

PLUGINDIR=$(dirname $0)
if [ -f $PLUGINDIR/utils.sh ]; then
	. $PLUGINDIR/utils.sh
else
	STATE_OK=0
	STATE_WARNING=1
	STATE_CRITICAL=2
	STATE_UNKNOWN=3
	STATE_DEPENDENT=4
fi

if [ $# -ne  1 ] && [ $# -ne 2 ]; then
    echo "Usage: ${0##*/} <service name> [<is_mount>]"
    exit $STATE_UNKNOWN
fi

service=$1

is_mount=$2

if [[ -z ${is_mount} ]]; then
	status=$(systemctl is-enabled $service 2>/dev/null)
	r=$?
	if [[ -z "$status" ]]; then
	echo "ERROR: service $service doesn't exist"
	exit $STATE_CRITICAL
	fi

	if [[ $r -ne 0 ]]; then
	    echo "ERROR: service $service is $status"
	    exit $STATE_CRITICAL
	fi
fi

systemctl --quiet is-active $service
if [[ $? -ne 0 ]]; then
    echo "ERROR: service $service is not running"
    exit $STATE_CRITICAL
fi

echo "OK: service $service is running"
exit $STATE_OK
